diff --git a/web/src/components/delegation/DelegateProfile.tsx b/web/src/components/delegation/DelegateProfile.tsx
index 4093c10c..36ebbd4a 100644
--- a/web/src/components/delegation/DelegateProfile.tsx
+++ b/web/src/components/delegation/DelegateProfile.tsx
@@ -159,7 +159,7 @@ const DelegateProfile: React.FC = () => {
setProfileData({...profileData, minDelegation: e.target.value})}
/>
@@ -169,7 +169,7 @@ const DelegateProfile: React.FC = () => {
setProfileData({...profileData, maxDelegation: e.target.value})}
/>
@@ -231,7 +231,7 @@ const DelegateProfile: React.FC = () => {
- 0 PZK
+ 0 HEZ
{t('delegation.totalReceived')}
@@ -259,7 +259,7 @@ const DelegateProfile: React.FC = () => {
{t('delegation.delegationLimits')}
- Min: {profileData.minDelegation} PZK | Max: {profileData.maxDelegation} PZK
+ Min: {profileData.minDelegation} HEZ | Max: {profileData.maxDelegation} HEZ
diff --git a/web/src/components/proposals/ProposalWizard.tsx b/web/src/components/proposals/ProposalWizard.tsx
index a22563fc..529a8176 100644
--- a/web/src/components/proposals/ProposalWizard.tsx
+++ b/web/src/components/proposals/ProposalWizard.tsx
@@ -208,7 +208,7 @@ const ProposalWizard: React.FC = ({ onComplete, onCancel })
type="number"
value={proposalData.budget}
onChange={(e) => setProposalData({...proposalData, budget: e.target.value})}
- placeholder="Amount in PZK"
+ placeholder="Amount in HEZ"
/>
)}
@@ -308,7 +308,7 @@ const ProposalWizard: React.FC = ({ onComplete, onCancel })
{proposalData.budget && (
{t('proposals.fields.budget')}:
-
{proposalData.budget} PZK
+
{proposalData.budget} HEZ
)}
diff --git a/web/src/components/treasury/TreasuryOverview.tsx b/web/src/components/treasury/TreasuryOverview.tsx
index d49819cf..d595bc1b 100644
--- a/web/src/components/treasury/TreasuryOverview.tsx
+++ b/web/src/components/treasury/TreasuryOverview.tsx
@@ -91,7 +91,7 @@ export const TreasuryOverview: React.FC = () => {
Live Blockchain Data
- {proposals.length} active proposals • {metrics.totalBalance.toFixed(2)} PZKW in treasury
+ {proposals.length} active proposals • {metrics.totalBalance.toFixed(2)} HEZ in treasury
diff --git a/web/src/components/wallet/TransactionModal.tsx b/web/src/components/wallet/TransactionModal.tsx
index 892066a9..227c5a56 100644
--- a/web/src/components/wallet/TransactionModal.tsx
+++ b/web/src/components/wallet/TransactionModal.tsx
@@ -94,11 +94,11 @@ export const TransactionModal: React.FC = ({
- {type === 'send' ? 'Send PZK' : type === 'vote' ? 'Cast Vote' : 'Delegate Voting Power'}
+ {type === 'send' ? 'Send HEZ' : type === 'vote' ? 'Cast Vote' : 'Delegate Voting Power'}
- {type === 'send'
- ? 'Send PZK tokens to another address'
+ {type === 'send'
+ ? 'Send HEZ tokens to another address'
: type === 'vote'
? 'Submit your vote for the proposal'
: 'Delegate your voting power to another address'}
@@ -120,7 +120,7 @@ export const TransactionModal: React.FC = ({
/>
-
+
{
{formatAddress(address!)}
-
{formatBalance(balance)} PZK
+
{formatBalance(balance)} HEZ
{!isCorrectNetwork && (
@@ -74,7 +74,7 @@ export const WalletButton: React.FC = () => {
Balance
-
{formatBalance(balance)} PZK
+
{formatBalance(balance)} HEZ
diff --git a/web/src/components/delegation/DelegationManager.tsx b/web/src/components/delegation/DelegationManager.tsx
index f1df2400..795de5df 100644
--- a/web/src/components/delegation/DelegationManager.tsx
+++ b/web/src/components/delegation/DelegationManager.tsx
@@ -22,7 +22,7 @@ const DelegationManager: React.FC = () => {
const [delegationAmount, setDelegationAmount] = useState('');
const [delegationPeriod, setDelegationPeriod] = useState('3months');
// Format token amounts from blockchain units (assuming 12 decimals for PZKW)
const formatTokenAmount = (amount: string | number) => {
const value = typeof amount === 'string' ? BigInt(amount) : BigInt(amount);
return formatNumber(Number(value) / 1e12, 2);
@@ -175,7 +175,7 @@ const DelegationManager: React.FC = () => {
- {formatTokenAmount(delegate.totalDelegated)} PZKW delegated
+ {formatTokenAmount(delegate.totalDelegated)} HEZ delegated
@@ -209,7 +209,7 @@ const DelegationManager: React.FC = () => {
setDelegationAmount(e.target.value)}
/>
@@ -275,7 +275,7 @@ const DelegationManager: React.FC = () => {
{delegation.delegate}
{delegation.delegateAddress}
- {formatTokenAmount(delegation.amount)} PZKW
+ {formatTokenAmount(delegation.amount)} HEZ
Conviction: {delegation.conviction}x
{delegation.category && {delegation.category}}
@@ -22,7 +22,7 @@ const DelegationManager: React.FC = () => {
const [delegationAmount, setDelegationAmount] = useState('');
const [delegationPeriod, setDelegationPeriod] = useState('3months');
- // Format token amounts from blockchain units (assuming 12 decimals for PZKW)
+ // Format token amounts from blockchain units (assuming 12 decimals for HEZ)
const formatTokenAmount = (amount: string | number) => {
const value = typeof amount === 'string' ? BigInt(amount) : BigInt(amount);